% function compute_steady_state_growth

% Compute steady state Growth model
% Pablo A. Guerron-Quintana
% Federal Reserve Bank of Philadelphia
% August 12, 2013

% param.zet   = 1 ;
% param.eta   = 0.8 ;    % C-G
% param.grows = 0.5 ;      % 2 percent annual growth
% param.sige  = 0.06 ;
% param.nu    = 1.6 ;    % C-G
% param.deltan= 0.03 ;   % C-G
% param.delta0= 0.025 ;
% param.phiks = 0.23 ;
% param.theta = 0.23 ;  % Shi
% param.rhoa  = 0.95 ;
% param.rhophik= 0.9 ;
% param.alph  = 0.36 ;
% param.curlyeps = (1-param.alph)/(param.nu-param.alph)  ; % Condition to make linear prod function
% param.d2d1  = 1 ;  % elasticity of cap util
% param.kappa = 5 ;
% param.utils = 0.8 ;
% param.sgs    = 0.2 ;
% param.rhog  = 0.5 ;
% param.rhopsia = 0.75 ;
% param.rhochi = 0.9 ;
% param.rhobet = 0.9 ;
% param.sy = 0.015 ; % sigm*st/yt = 1.5 percent R&D investment to GDP 
%                   % according to NIPA accounts for 1999 - 2012
%                   % set chi
% 
% zet     = param.zet ;
% eta     = param.eta ;
% grows   = param.grows ;
% sige    = param.sige ;
% sigw    = 1 - sige ;
% nu      = param.nu ;
% curlyeps= param.curlyeps ;
% deltan  = param.deltan ;
% delta0  = param.delta0 ;
% phiks   = param.phiks ;
% theta   = param.theta ;
% rhoa    = param.rhoa ;
% rhophik = param.rhophik ;
% alph    = param.alph ;
% d2d1    = param.d2d1 ;
% kappa   = param.kappa ;
% utils   = param.utils ;
% sgs     = param.sgs ;
% rhog    = param.rhog ;
% rhopsia = param.rhopsia ;
% rhochi  = param.rhochi ;
% rhobet  = param.rhobet ;
% sy      = param.sy ;

% get_parameters_growth ;

% shocks in ss
at      = 1 ;
atp     = at ;

alagt   = at ;
alagtp  = alagt ;

phikt    = phiks ;
phiktp   = phikt ;

sgt      = sgs ;
sgtp     = sgt ;

meit    = 1 ;
meitp   = meit ;

uskt    = 1 ;
usktp   = uskt ;

swshkt  = 1 ;
swshktp = swshkt ;

% some normalizations

grows   = 1 + grows/100 ;
growt   = grows ;

labt    = 1/3 ;
labtp   = labt ;

yt      = 1 ;
ytp     = 1 ;
yts     = 1 ;


utilt   = utils ;
utiltp  = utilt ;

pkt     = 1  ;
pktp    = pkt ;

mtps    = bet*growt^(-1/ppsi) ;

%xxm = [0.2 2 0.1 1] ;
%findsigepnt(xxm,mtps,growt,phikt,theta,invsh,rdsh,lsh,deltan,delta0,taup,taul,ppsi,sgs,labt) ;

% Solve for alph nu cet pnt 
% benchmark
[xsol,fval,exitflag]    = fsolve(@(xx) findsigepnt(xx,mtps,growt,phikt,theta,invsh,rdsh,lsh,deltan,delta0,taup,taul,ppsi,sgs,labt),[0.2 3 0.05 3],optimset('Display','off','MaxFunEvals',5000,'MaxIter',5000)) ;
% different omega
% Comment lines 107 and 122; uncomment 111 and 112
% baseline omega = 0.796
% omega   = 0.5 ;% less elastic labor supply  
% [xsol,fval,exitflag]    = fsolve(@(xx) findsigepnt_omega(xx,mtps,growt,phikt,theta,invsh,rdsh,lsh,deltan,delta0,taup,taul,ppsi,sgs,labt,omega),[0.2 3 0.05 3],optimset('Display','off','MaxFunEvals',5000,'MaxIter',5000)) ;

if exitflag == 1
    % good solution
    alph    = xsol(1) ;
    nu      = xsol(2) ;
    cet     = xsol(3) ;
    pnt     = xsol(4) ;
    
    % other variables
    omega   = 1 - alph ; 
    curlyeps= (1 - alph)/(nu - alph) ;
    rd      = (1 - curlyeps/nu)*rdsh ;
    varthet = (growt - 1 + deltan)/rd ;
    uR      = (1 - curlyeps)*alph/((1 - curlyeps/nu)*invsh/(growt - 1 + delta0)) ;
    
    if varthet*pnt > 1/theta || varthet*pnt < 1
        disp('constraint violated')
        exitflags = 4 ;
        return ;
    end
elseif exitflag ~= 1 || sum(imag(xsol)) ~= 0
    disp('no solution pnt')
    exitflags = 4 ;
    return
end

lame    = (pnt*varthet - 1)/(1 - theta*pnt*varthet) ;
sige    = (1/mtps - uR*(1 - taup) + delta0 - 1)/(lame*(uR*(1 - taup) + phikt*(1 - delta0))) ;
sigw    = 1 - sige ;

invt    = (1 - curlyeps/nu)*invsh/sigw ;
invtp   = invt ;

kt      = sigw*invt/(growt - 1 + delta0) ;
ktp     = kt ;

proft   = (nu - 1)*curlyeps/nu ;

cwt     = ((1 + lame)^ppsi*cet - (1 - taul)*(1 - curlyeps)*(1 - alph)*(1 - labt)/(labt*omega*(1 - sige))) ;
cwtp    = cwt ;

st      = rd/sige ;
stp     = st ;

wt      = (1 - curlyeps)*(1 - alph)*yt/(labt*sigw) ;
wtp     = wt ;

if (cet <= 0 || cwt <= 0)
    error('negative consumption!')
    exitflags = 4 ;
    return    
end

ct      = sige*cet + sigw*cwt ;
ctp     = ct ;

Rt      = (1 - curlyeps)*alph/(kt*utilt) ;
Rtp     = Rt ;

stockt  = pkt*(1 - delta0)*kt + pnt*growt ;
stocktp = stockt ;

% Some normalization constants
psia    = (1 - taul)*wt/(pkt*kt*(1-labt)^(omega-1)) ;
chi     = varthet*(sige*st)^(1-eta) ;
capA    = (yt/((utilt*kt)^alph*(sigw*labt)^(1-alph)))^(1/(1-alph)) ;
delta1  = Rt*(1 - taup)*(1 + sige*lame)/(pkt*(1 + sige*lame*phikt)) ;
delta2  = delta1*delta2/utilt ;

psiat   = psia ;
psiatp  = psia ;

chit    = 1 ; % chi ;
chitp   = chit ;

betat   = bet ;
betatp  = betat ;

ylagt   = yt ; ylagtp  = ylagt ;
clagt   = ct ; clagtp  = clagt ;
wlagt   = wt ; wlagtp  = wlagt ;
slagt   = st ; slagtp  = slagt ;
invlagt = invt ; invtlagtp = invlagt ;
stocklagt = stockt ; stocklagtp = stocklagt ;
utilagt = utilt ; utilagtp = utilagt ;

dyt     = growt ; dytp = dyt ;
dct     = growt ; dctp = dct ;
dinvt   = growt ; dinvtp = dinvt ;
dwt     = growt ; dwtp = dwt ;
dst     = growt ; dstp = dst ;
dstkt   = growt ; dstktp = dstkt ;
dtfpt   = exp((1 - alph)*log(growt) + alph*log(utilt/utilagt) + (1 - alph)*log(atp/at)) ; dtfptp = dtfpt ;
swt     = 1 ; swtp = swt ;

ss_to_logs