% Format data for estimation Growth Model with Financial Frictions
% PaGq-RJ

% 1. Read data

% order: Y C I R&D w h P util stock gtfp SW
% 1970Q1 - 2011Q4  
[dat,txt] = xlsread('US_data_rev2.xlsx','nominal') ;

% 2. Transform data

% 2.1 Real variables
dat(:,[1:5 9]) = dat(:,[1:5 9])./repmat(dat(:,7),1,6) ;

% some valuable statistics
disp(sprintf('mean I/Y:  %6.5f',mean(dat(:,3)./dat(:,1)))) ;
disp(sprintf('mean R&D/Y:  %6.5f',mean(dat(:,4)./dat(:,1)))) ;

% 2.2 natural log
dat(:,1:9) = log(dat(:,1:9)) ;
dat(:,7)   = [] ; % remove price level

% 2.3 growth rates but labor and utilization
%     divide gtfp by 100 to make it quarterly and same size as order vars
%     divide SW by -100 to make it compatible with phik (opposite sign)
zzd        = [dat(2:end,1:5)-dat(1:end-1,1:5) dat(2:end,6) dat(2:end,7) dat(2:end,8)-dat(1:end-1,8) dat(2:end,9)/400 -dat(2:end,10)/100] ;
% hp-filter labor
[~,zzd(:,6)] = hpfilter(zzd(:,6),1600) ;
zzd = 100*zzd ;

% 2.4 remove mean
disp(sprintf('quarterly gdp growth mean: %6.5f',mean(zzd(:,1)))) ;

for ix = 1:9
    zzd(:,ix) = zzd(:,ix) - mean(zzd(:,ix)) ;
end

% 3. Plot
 figure
 time = 1970.25:.25:2011.75 ;
 varn = char('dY','dC','dI','dRD','dW','H','util','dstock','dTFP','SW-PCfin') ;
 for ix = 1:10
     subplot(2,5,ix)
     plot(time,zzd(:,ix),'LineWidth',1.5)
     title(varn(ix,:)) ;
     axis tight
 end

% 3. Re-order variables
% model: dyt dct dinvt dwt labt swt dstkt dtfpt
% data:   Y   C    I    R&D w h util dstock gTFP SW
zzd = [zzd(:,1:3) zzd(:,5:6) zzd(:,10) zzd(:,8:9) zzd(:,4)] ;