function lik = growth_max(xx,par,zzd,maxop)
% % Solve model and compute likelihood
% % PaGq
% % Federal Reserve Bank of Phildelphia
% % Feb 1, 2013
% % Revision Dec 2014
% 

if maxop == 1
    xx  =   map(xx) ;
end
 
if imag(xx(:)')*imag(xx(:)) ~= 0
    lik = 10000000000 ;
    return
end
 
% Unwrap parameters
growthundo ;

% Compute steady state
exitflags = 0 ;
compute_steady_state_growth

if exitflags == 4
    lik = 100000000 ;
    return
end

% Compute derivatives if needed
% [~,~,~,~,~,~] = model_for_estimation ;

% numerical evaluation
growfinfric_num_eval ;

ne = 7 ; % six shocks
nstates = size(nfx,2) ;
npsvar  = size(nfy,2) ;

if abs(nf(:)'*nf(:))> 1e-11 || isinf(([nfx(:);nfxp(:);nfy(:);nfyp(:)]'* ...
        [nfx(:);nfxp(:);nfy(:);nfyp(:)])) == 1 ...
        || isnan(([nfx(:);nfxp(:);nfy(:);nfyp(:);]'* ...
        [nfx(:);nfxp(:);nfy(:);nfyp(:)])) == 1 ; 
    gx = zeros(npsvar,nstates)  ;
    hx = zeros(nstates,nstates) ;
    exitflags = 4 ; % error in numerical evaluation
    lik = 100000000 ;
    % disp('error nf in ss')
    return
end

% number of structural shocks
ETAMATRIX = zeros(size(nfx,2),ne); 
ETAMATRIX(end-7,1)  = sigmau ;
ETAMATRIX(end-6,2)  = sigmam ;
ETAMATRIX(end-5,3)  = sigmaa ;
ETAMATRIX(end-4,4)  = sigmapk ;
ETAMATRIX(end-3,5)  = sigmag ;
ETAMATRIX(end-2,6)  = sigmaps ;
ETAMATRIX(end-1,7)  = sigmac ;
ETAMATRIX(end,8)    = sigmab ;

% solve gx hx
[gx,hx,exitflags] = gx_hx_new_short(nfy,nfx,nfyp,nfxp) ;

if exitflags ~= 1
    lik = 100000000 ;
    return
end

% plot IRFs
% plot_irfs_growth ;

% evaluate likelihood
[lik,~]   = linear_growth(gx,hx,nstates,npsvar,ne,ETAMATRIX,zzd) ;
logprior  = priorgrowth(xx) ;

if imag(lik) ~= 0 || imag(logprior) ~= 0 || isnan(lik) == 1 || isnan(logprior) == 1
    lik = 100000000 ;
    return
end

lik = - lik - logprior ;

% return ;

% % smoother
rhostruc.rhoa   = rhoa ;
rhostruc.rhophik = rhophik ; 
rhostruc.rhog   = rhog ; 
rhostruc.rhopsia = rhopsia ; 
rhostruc.rhochi = rhochi ; 
rhostruc.rhobet = rhobet ; 
rhostruc.rhomei = rhomei ;
rhostruc.rhou   = rhou ;
rhostruc.rhosw  = rhosw ;
 
[~,~] = linear_growth_smoother(gx,hx,nstates,npsvar,ne,ETAMATRIX,zzd,rhostruc,alph) ;
return 