function [lik,spred] = linear_growth_smoother(gx,hx,nstates,~,measerr,ETAMATRIX,zz,rhostruc,~)

% Objective: Compute smoothed shocks
% Growth model; linear approximation
% Pablo A. Guerron-Quintana
% Feb, 2 2013
% Revision Jan 2015
measerr = 7 ;
T   = size(zz,1) ;                                  % Number of time observations
R   = zeros(measerr) ;      % KF's measurement noise variance, no measure errors 
Q   = zeros(nstates,nstates) ;
Q(end-7:end,end-7:end) = ETAMATRIX(end-7:end,:) ;   % KF's process noise variance; see notes in pages 3
Q   = Q.^2 ;
S0  = zeros(nstates,1) ;                     % initial state
% Q   = [gx;eye(nstates)]*Q*[gx;eye(nstates)]' ;
% S0  = zeros(nstates+npsvar,1) ;                     % initial state

% format matrices

F       = hx ; % [zeros(size(gx,1),npsvar) gx*hx; zeros(size(hx,1),npsvar) hx] ;
H       = gx ;
H       = 100*H([1:3 5:8],:) ;

C       = zeros(nstates,1) ;
c       = zeros(measerr,1) ;  

% initialize lik

P0    = eye(nstates^2)/(eye(((nstates)^2))-kron(F,F))*reshape(Q,((nstates)^2),1);
P0    = reshape(P0,nstates,nstates);

lik     = 0 ;
sig     = P0 ;
shat    = S0 ;
ypred   = zeros(T,measerr) ;

for t=1:T,    
  
  % Kalman Filter step
  % =================================
  
  [shatnew,signew,sigpred(:,:,t),ypred(t,:)] = ksmoother(zz(t,[1:3 5:8])',H,F,c,C,shat,sig,R,Q) ;

  shat = shatnew ;
  sig  = signew ;
  
  spred(t,:) = shatnew ;
  sigup(:,:,t) = signew ;
  
end;   % End of t loop.

ssmooth = zeros(size(spred)) ;
ssmooth(T,:) = spred(T,:) ;
Ftra = F' ;
sigsmooth = sigpred(:,:,T) ;

for t = T-1:-1:1
    isig = pinv(sigpred(:,:,t+1)) ; % (sigpred(:,:,t+1))\eye(size(sigpred(:,:,t+1))) ;
    ssmooth(t,:) = (spred(t,:)' + sigup(:,:,t)*Ftra*isig*(ssmooth(t+1,:)'-F*spred(t,:)'-C))' ;
    sigsmooth   = sigup(:,:,t) + sigup(:,:,t)*Ftra*isig*(sigsmooth - sigpred(:,:,t+1))*(isig)'*F*sigup(:,:,t)' ;
    
end

% Recover shocks
rhos = [rhostruc.rhou rhostruc.rhomei rhostruc.rhoa rhostruc.rhophik rhostruc.rhog rhostruc.rhopsia rhostruc.rhochi rhostruc.rhobet] ;

% order in shocks is reversed
% bet chi psia sg phik a mei u
shocks = zeros(measerr,T) ;

for t = 1:T
    for ix = 1:measerr
        if t == 1
            shocks(ix,t) = ssmooth(t,end-ix+1) ;
        else
            shocks(ix,t) = ssmooth(t,end-ix+1) - rhos(end-ix+1)*ssmooth(t-1,end-ix+1) ;
        end
    end
end

time = 1970.25:.25:2011.75 ;
tini = find(time == 2008.75) ;
% tini = find(time == 2007.5) ; % begining of crisis
% tini = find(time == 2007.25) ; % for counter 2007.Q2 frozen liq shock
% tini = find(time == 2008.25) ;
tbeg = find(time == 2005);
tbeg1 = find(time == 2005) ;
t2000 = find(time == 2005) ;
t2008q3 = find(time == 2008.5) ;

% Plot smoothed innovations
varn = char('\beta','\chi','$$\varphi$$','g','\phi','A','m','tfp') ;
varny= char('dY','dC','dI','dw','lab','SW','Stock','TFP') ;
varnyl= char('Y','C','I','w','lab','SW','Stock','TFP') ;

% plot smoothed stochastic processes
figure(4)
for ix = 2:8
    subplot(4,2,ix-1)
    hold on
    plot(time(t2000:end),ssmooth(t2000:end,end-ix+1),'LineWidth',1.5)
    plot(time(t2008q3),ssmooth(t2008q3,end-ix+1),'ro','LineWidth',2) ;
    line(time(t2000:end),0*[1:length(time(t2000:end))],'LineWidth', 1.5, 'Color', 'k', 'LineStyle', ':')
    axis tight
    if ix == 3
        str = sprintf('$$\\varphi $$');
        lh = title(str) ;
        set(lh,'Interpreter','latex','Fontsize',10)
    else
        title(varn(ix,:),'Fontsize',10) ;
    end
    hold off
end

% Uncomment next line to generate the shocks back to trend
trend_actual_constant ;
pause
return 

