function [fx,fxp,fy,fyp,nstates,npsvar] = model_for_estimation 

% This program computes analytical first and second derivatives of the
% function f for growth model with financial frictions
% E_t f(yp,y,xp,x) =0. 
%
% Inputs: none
%
% Output: Analytical first and second derivatives of the function f
%
% Calls: anal_deriv.m by Schmitt and Uribe
%
% (c) Pablo A. Guerron-Quintana; Philadelphia Fed
% Date: First Version August 12, 2013
%       Revision March 23, 2015
%       New utility function

% Endogenous variables
syms st wt yt labt cet cwt pnt proft varthet ct clagt ylagt wlagt slagt dyt dct dwt dst celagt cwlagt utilagt utilagtp
syms stp wtp ytp labtp cetp cwtp pntp proftp varthetp ctp clagtp ylagtp wlagtp slagtp dytp dctp dwtp dstp alagt alagtp
syms mt mtp invt invtp invlagt invlagtp utilt utiltp pkt pktp kt ktp Rt Rtp stocklagt stocklagtp dstkt dstktp celagtp cwlagtp
syms growt growtp deprt deprtp deprpt deprptp Scost Scostp Scospt Scosptp dinvt dinvtp govtp stockt stocktp stocktp dtfpt dtfptp

% Shocks
syms at atp sgt sgtp psiat psiatp chit chitp uskt meit swt swtp
syms phikt phiktp betat betatp usktp meitp swshkt swshktp

% Parameters
syms bet alph nu curlyeps  sigw sige theta capA deltan chi eta psia
syms delta0 delta1 delta2 phiks alph kappa utils grows sigmapk
syms rhophik rhoa rhog sgs rhopsia rhochi rhobet rhou rhomei rhosw
syms ppsi omega yts
syms taup taul habit bet

% Some identities 

yt      = (utilt*kt)^alph*(capA*at*sigw*labt)^(1-alph) ; % ok
mtp     = bet*(growtp*(cwtp + psiatp*pktp*ktp*(1-labtp)^omega/omega)/(cwt + psiat*pkt*kt*(1-labt)^omega/omega))^(-1/ppsi) ; % Changed                 
varthet = chi*(sige*st)^(eta-1) ; % ok
varthetp= chi*(sige*stp)^(eta-1) ; % ok
deprt   = (delta0 + delta1*(utilt - utils) + delta2/2*(utilt - utils)^2) ;
deprtp  = (delta0 + delta1*(utiltp - utils) + delta2/2*(utiltp - utils)^2) ;
deprpt  = (delta1 + delta2*(utilt - utils)) ;
deprptp = (delta1 + delta2*(utiltp - utils)) ;
Scost   = kappa*(growt*invt/invlagt - grows)^2/2 ;
Scostp  = kappa*(growtp*invtp/invlagtp - grows)^2/2 ;
Scospt  = kappa*(growt*invt/invlagt - grows) ;
Scosptp = kappa*(growtp*invtp/invlagtp - grows) ;

% Model
f1      = -psiat*pkt*kt*(1-labt)^(omega-1) + wt*(1 - taul) ; % ok

f2      = -wt + (1-curlyeps)*(1-alph)*yt/(sigw*labt) ; % ok

f3      = -cet*(1 + (pnt*varthet-1)/(1-theta*pnt*varthet))^ppsi + (cwt + psiat*pkt*kt*(1-labt)^omega/omega) ; % ok

f4      = -pnt + mtp*(proftp*(1-taup) + pntp*(1 - deltan) + sige*((pntp*varthetp-1)/(1-theta*pntp*varthetp))*(proftp*(1 - taup) + pntp*(1-deltan)*phiktp)); % ok

f5      = -proft + (nu-1)*curlyeps*yt/nu ; % ok

f6      = -Rt + (1 - curlyeps)*alph*yt/(utilt*kt) ; % ok

f7      = -pkt + mtp*(utiltp*Rtp*(1-taup) + pktp*(1 - deprtp) + sige*(pntp*varthetp-1)/(1-theta*pntp*varthetp)*(utiltp*Rtp*(1-taup) + pktp*(1 - deprtp)*phiktp)) ; % ok

f8      = (1-taup)*Rt - pkt*deprpt + sige*(pnt*varthet-1)/(1-theta*pnt*varthet)*(Rt*(1-taup) - pkt*phikt*deprpt) ; % ok

f9      = -1/chit + pkt*(1 - Scost - Scospt*(growt*invt/invlagt)) + mtp*pktp*Scosptp*(growtp*invtp/invt)^2 ; % ok

f10     = -(1 - theta*pnt*varthet)*st - cet + proft + utilt*Rt*kt + phikt*(pnt*(1 - deltan) + pkt*(1 - deprt)*kt) + sigw*taul*wt*labt - sgt*(1 - curlyeps/nu)*yts ; % new

f11     = -growtp + 1 - deltan + varthet*sige*st ; % new

% Modified to set Gt a function of steady state GDP @ March 3, 2015
f12     = -(1-curlyeps/nu)*yt + ct + sige*st + sigw*invt/chit + (1-curlyeps/nu)*yts*sgt ; % ok

f13     = -growtp*ktp + (1 - deprt)*kt + (1 - Scost)*sigw*invt ; % ok

f14     = -stockt + pkt*(1 - deprt)*kt + pnt*growtp ; % new

f15     = -ct + sige*cet + sigw*cwt ; % ok

f16     = -yt + ylagtp ; % ok
    
f17     = -ct + clagtp ; % ok

f18     = -wt + wlagtp ;

f19     = -invt + invlagtp ;

f20     = -st + slagtp ;

f21     = -stockt + stocklagtp ;

f22     = -utilt + utilagtp ;

f23     = -alagtp + at ;

% Growth rate of gross output (yt) and value added output (curly yt) is the
% same in this model.

f24     = -dyt + yt*growt/ylagt ;

f25     = -dct + ct*growt/clagt ;

f26     = -dwt + wt*growt/wlagt ;

f27     = -dinvt + invt*growt/invlagt ;

f28     = -dst + st*growt/slagt ;

f29     = -dstkt + stockt*growt/stocklagt + log(meit) ;

f30     = -(swt) + (phikt-phiks) + 1 ;

% f31     = -log(dtfpt) + (1 - alph)*log(growt) + alph*log(utilt/utilagt) + (1 - alph)*log(at/alagt) ;
f31     = -dtfpt + growt^(1 - alph)*(utilt/utilagt)^alph*(at/alagt)^(1 - alph) + log(uskt) ;

f32     = -log(usktp) + rhou*log(uskt) ;

f33     = -log(meitp) + rhomei*log(meit) ;

f34     = -log(atp) + rhoa*log(at) ;

f35     = -log(phiktp/phiks) + rhophik*log(phikt/phiks) ;

f36     = -log(sgtp/sgs) + rhog*log(sgt/sgs) ;

f37     = -log(psiatp/psia) + rhopsia*log(psiat/psia) ;

f38     = -log(chitp) + rhochi*log(chit) ;

f39     = -log(betatp/bet) + rhobet*log(betat/bet) ;

% Define the vector of controls, y, and states, x

xr  = [ylagt clagt invlagt wlagt slagt kt growt stocklagt utilagt alagt uskt meit at phikt sgt psiat chit betat] ;
yr  = [dyt dct dinvt dwt labt swt dstkt dtfpt dst stockt wt invt utilt ct cet cwt st pnt pkt Rt proft] ;
xrp = [ylagtp clagtp invlagtp wlagtp slagtp ktp growtp stocklagtp utilagtp alagtp usktp meitp atp phiktp sgtp psiatp chitp betatp] ;
yrp = [dytp dctp dinvtp dwtp labtp swtp dstktp dtfptp dstp stocktp wtp invtp utiltp ctp cetp cwtp stp pntp pktp Rtp proftp] ;

% Make f a function of the logarithm of the state and control vector
% f = subs(f, [xr,yr,xrp,yrp], exp([xr,yr,xrp,yrp])); % don't work in

f = [f1;f2;f3;f4;f5;f6;f7;f8;f9;f10;f11;f12;f13;f14;f15;f16;f17;f18;f19;f20;f21;f22;f23;f24;f25;f26;f27;f28;f29;f30;f31;f32;f33;f34;f35;f36;f37;f38;f39] ;

f = subs(f, [xr,yr,xrp,yrp], exp([xr,yr,xrp,yrp]));

%Compute analytical derivatives of f
[fx,fxp,fy,fyp,~,~,~,~,~,~,~,~,~,~,~,~,~,~,~,~]=anal_deriv(f,xr,yr,xrp,yrp);

anal_deriv_print2f('growfinfric',fx,fxp,fy,fyp,f);

nstates     = size(xr,2) ; % number of state variables in DSGE model; 
npsvar      = size(yr,2) ; % number of control variables in DSGE; these are pseudo observable in measurement equation